Pydantic models for GeoZarr conventions.

## Spatial

::: geozarr_toolkit.Spatial
    options:
      show_source: false

::: geozarr_toolkit.SpatialConventionMetadata
    options:
      show_source: false

### Proj Convention

::: geozarr_toolkit.Proj
    options:
      show_source: false

::: geozarr_toolkit.ProjConventionMetadata
    options:
      show_source: false

### Multiscales Convention

::: geozarr_toolkit.Multiscales
    options:
      show_source: false

::: geozarr_toolkit.MultiscalesConventionMetadata
    options:
      show_source: false

::: geozarr_toolkit.ScaleLevel
    options:
      show_source: false

::: geozarr_toolkit.Transform
    options:
      show_source: false

### Base Convention

::: geozarr_toolkit.ZarrConventionMetadata
    options:
      show_source: false